DataTables example - Ajax data source (arrays)

# DataTables example Ajax data source (arrays)

DataTables has the ability to read data from virtually any JSON data source that can be obtained by Ajax. This can be done, in its most simple form, by setting the `ajaxDT` option to the address of the JSON data source.

The `ajaxDT` option also allows for more advanced configuration such as altering how the Ajax request is made. See the `ajaxDT` documentation or the other Ajax examples for DataTables for further information.

By default DataTables will assume that an array data source is to be used and will read the information to be displayed in each column from the row's array using the column index, making working with arrays very simple (note that this can be changed, or objects used may using the `columns.dataDT` option, shown in other examples).

The example below shows DataTables loading data for a table from arrays as the data source, where the structure of the row's data source in this example is:

    [
    	"Tiger Nixon",
    	"System Architect",
    	"Edinburgh",
    	"5421",
    	"2011/04/25",
    	"$3,120"
    ]

Name | Position | Office | Extn. | Start date | Salary
--- | --- | --- | --- | --- | ---
Name | Position | Office | Extn. | Start date | Salary

- Javascript
- HTML
- CSS
- Ajax
- Server-side script

The Javascript shown below is used to initialise the table shown in this example:

`$(document).ready(function() { $('#example').dataTable( { "ajax": "data/arrays.txt" } ); } );`

In addition to the above code, the following Javascript library files are loaded for use in this example:

- ../../media/js/jquery.js
- ../../media/js/jquery.dataTables.js

The HTML shown below is the raw HTML table element, before it has been enhanced by DataTables:

This example uses a little bit of additional CSS beyond what is loaded from the library files (below), in order to correctly display the table. The additional CSS used is shown below:

``

The following CSS library files are loaded for use in this example to provide the styling of the table:

- ../../media/css/jquery.dataTables.css

This table loads data by Ajax. The latest data that has been loaded is shown below. This data will update automatically as any additional data is loaded.

The script used to perform the server-side processing for this table is shown below. Please note that this is just an example script using PHP. Server-side processing scripts can be written in any language, using the protocol described in the DataTables documentation.